@@ -27,6 +27,7 @@
 
 
 #include <stdio.h>
+#include "alloc.h"
 #include "longbits.h"
 #include "align32.h"
 #include "endian_calc.h"
@@ -35,6 +36,9 @@
 #include "sha1.h"
 
 
+#include "banned.h"	/* include after system header <> includes */
+
+
 /*
  * The SHA1 f()-functions.  The f1 and f3 functions can be optimized
  * to save one boolean operation each - thanks to Rich Schroeppel,
